# Generated by Django 2.0.7 on 2019-12-20 07:13

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='Feedback',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('subject', models.CharField(max_length=255, verbose_name='Subject')),
                ('name', models.CharField(blank=True, max_length=255, verbose_name='Name')),
                ('mobile', models.CharField(blank=True, max_length=255, verbose_name='Mobile')),
                ('email', models.EmailField(blank=True, max_length=255, verbose_name='Email')),
                ('date_created', models.DateTimeField(auto_now_add=True, verbose_name='Date created')),
                ('text', models.TextField(max_length=4096, verbose_name='Message text')),
                ('user', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL, verbose_name='User')),
            ],
            options={
                'verbose_name': 'Feedback message',
                'verbose_name_plural': 'Feedback messages',
            },
        ),
    ]
